pub enum TermT {
Comp(Vec<TermT>),
Tensor(Vec<TermT>),
Id(TermType),
Phase(Phase),
IfLet {
pattern: PatternT,
inner: Box<TermT>,
},
Gate {
name: Name,
def: Box<TermT>,
},
Inverse(Box<TermT>),
Sqrt(Box<TermT>),
}Expand description
Syntax of typed terms
Variants
Comp(Vec<TermT>)
A non-empty composition “t_1 ; … ; t_n”
Tensor(Vec<TermT>)
A tensor “t_1 x … x t_n”
Id(TermType)
An identity “id(n)”
Phase(Phase)
A (global) phase operator, e.g. “-1” or “ph(0.1pi)”
IfLet
An “if let” statement, “if let pattern then inner”
Gate
Top level symbol, a named gate
Inverse(Box<TermT>)
Inverse of a term “t ^ -1”
Sqrt(Box<TermT>)
Square root of a term “sqrt(t)”
Implementations
Sourceimpl TermT
impl TermT
Sourcepub fn eval<B: Buildable>(&self) -> B
pub fn eval<B: Buildable>(&self) -> B
Evaluate a term to a given Buildable type, expanding top level definitions
and evaluating inverse and sqrt macros.
In particular this can be used to generate a TermN from a TermT.